@@ -5,12 +5,12 @@ built_modules = list(name for name in
 shiboken_library_soversion = str(5.15)
 pyside_library_soversion = str(5.15)
 
-version = "5.15.2.1"
-version_info = (5, 15, 2.1, "", "")
+version = "5.15.12"
+version_info = (5, 15, 12, "", "")
 
-__build_date__ = '2024-08-11T10:26:02+00:00'
+__build_date__ = '2025-11-01T11:23:51+00:00'
 
-__build_commit_hash__ = '9282e03de471bb3772c8d3997159e49c113d7678'
-__build_commit_hash_described__ = 'v5.15.2.1'
+__build_commit_hash__ = 'b642cfa372ca04f8a09f2bc94f8718ab23911ac1'
+__build_commit_hash_described__ = 'v5.15.12-lts-lgpl'
 
-__setup_py_package_version__ = '5.15.2.1'
+__setup_py_package_version__ = '5.15.12'
